import os
os.system("git clone https://github.com/AMKCode/pyseing.git")
os.chdir("./pyseing/src")
os.system("git clone https://github.com/pybind/pybind11.git")

os.chdir("./build")
os.system("cmake ..")
os.system("make")
os.chdir("..")
os.chdir("..")
os.chdir("..")
os.system("cp ./pyseing/src/build/pyseing* .")

import pyseing



from setuptools import setup, find_packages
import codecs
import os

VERSION = '0.0.6'
DESCRIPTION = 'test1'
LONG_DESCRIPTION = 'test1 long description'

# Setting up
setup(
    name="pyseing",
    version=VERSION,
    author="dummy",
    author_email="<mao2@jhu.edu>",
    description=DESCRIPTION,
    long_description_content_type="text/markdown",
    long_description=LONG_DESCRIPTION,
    packages=find_packages(),
    install_requires=[],
    keywords=[],
    classifiers=[]
)
